pub fn detect(project_dir: &Path) -> Vec<&'static ClientAdapter>Expand description
Adapters whose config file or marker directory already exists under
project_dir — the clients this repo actually uses.
pub fn detect(project_dir: &Path) -> Vec<&'static ClientAdapter>Adapters whose config file or marker directory already exists under
project_dir — the clients this repo actually uses.