pub fn parse_identity(secret_key: &str) -> Result<Identity, CryptoError>Expand description
Parse a secret key from its string representation (AGE-SECRET-KEY-1…).
pub fn parse_identity(secret_key: &str) -> Result<Identity, CryptoError>Parse a secret key from its string representation (AGE-SECRET-KEY-1…).