pub fn parse_recipient(pubkey: &str) -> Result<Recipient, CryptoError>Expand description
Parse a public key from its string representation (age1…).
pub fn parse_recipient(pubkey: &str) -> Result<Recipient, CryptoError>Parse a public key from its string representation (age1…).