is_valid_key_name

Function is_valid_key_name 

pub fn is_valid_key_name(key: &str) -> bool
Check whether a key name is a valid shell identifier (safe for export KEY=...). Must start with a letter or underscore, and contain only [A-Za-z0-9_].