check_init_status

Function check_init_status 

pub fn check_init_status(
    vault: &Vault,
    secret_key: &str,
) -> Result<InitStatus, String>
Check whether a secret key is authorized in an existing vault.

Parses the identity from secret_key, checks the recipient list, and attempts to decrypt meta for the display name.