Structs
- Vault
Lock - An exclusive advisory lock on a vault file.
Enums
- Vault
Error - Errors that can occur during vault file operations.
Functions
- lock
- Acquire an exclusive advisory lock on the vault file.
- parse
- Parse vault from a JSON string.
- read
- Read a .murk vault file.
- read_
with_ raw - Read a .murk vault file and return both the parsed vault and the raw bytes.
- write
- Write a vault to a .murk file as pretty-printed JSON.