pub fn parse(contents: &str) -> Result<Vault, VaultError>Expand description
Parse vault from a JSON string.
Rejects vaults with an unrecognized major version to prevent silently misinterpreting a newer format.
pub fn parse(contents: &str) -> Result<Vault, VaultError>Parse vault from a JSON string.
Rejects vaults with an unrecognized major version to prevent silently misinterpreting a newer format.