pub struct VaultLock { /* private fields */ }Expand description
An exclusive advisory lock on a vault file.
Holds a .murk.lock file with an exclusive flock for the duration of a
read-modify-write cycle. Dropped automatically when the guard goes out of scope.