Enums
- Crypto
Error - Errors that can occur during crypto operations.
Functions
- decrypt
- Decrypt ciphertext using a secret key.
- encrypt
- Encrypt plaintext bytes to one or more recipients.
- parse_
identity - Parse a secret key from its string representation (AGE-SECRET-KEY-1…).
- parse_
recipient - Parse a public key from its string representation (age1…).