pub fn add_member(
murk: &mut Murk,
name: &str,
member_pubkey: &str,
operator_pubkey: &str,
) -> Result<bool, MurkError>Expand description
Add a member to a group. The group must exist, the operator must already be a member (so they can re-encrypt the group’s secrets), and the new member must be an authorized recipient. Returns true if the member was added (false if already present).