pub fn last_commit_signature(path: &str) -> Option<CommitSignature>Expand description
Return the signature status of the last commit touching path, or None
when git is unavailable, the repo has no such commit, or the path is
untracked — i.e. there is no git anchor to check.