pub fn revoke_recipient(
vault: &mut Vault,
murk: &mut Murk,
recipient: &str,
) -> Result<RevokeResult, MurkError>Expand description
Remove a recipient from the vault. recipient can be a pubkey or a display name.
When matched by display name, removes all recipients sharing that name
(e.g. multiple SSH keys added via github:username).
Returns an error if the recipient is not found or would remove the last recipient.