Recipient management: authorize and revoke vault access.
Structs
- Revoke
Result - Result of revoking a recipient.
Functions
- authorize_
recipient - Add a recipient to the vault. Returns an error if the pubkey is invalid or already present.
- revoke_
recipient - Remove a recipient from the vault.
recipientcan be a pubkey or a display name. Returns an error if the recipient is not found or is the last one.