Skip to main contentModule recovery
Source - RecoveryError
- Errors that can occur during recovery phrase operations.
- generate
- Generate a new age keypair and return the BIP39 24-word mnemonic,
secret key string, and public key string.
- phrase_from_key
- Re-derive the BIP39 24-word mnemonic from an existing MURK_KEY.
Decodes the Bech32 key back to raw bytes, then encodes as a mnemonic.
- recover
- Recover an age secret key from a BIP39 24-word mnemonic phrase.
Returns the same MURK_KEY that was originally generated.