pub fn read(path: &Path) -> Result<Vault, VaultError>Expand description
Read a .murk vault file.
Rejects symlinks at the vault path to prevent a local attacker from redirecting vault operations to a different project’s vault (and thus triggering auto key-file lookup against the attacker-controlled path).